/*! For license information please see calendar-node_modules_vue_dist_vue_runtime_esm-bundler_js-_7a231.js.LICENSE.txt */
"use strict";(self.webpackChunkcalendar=self.webpackChunkcalendar||[]).push([["node_modules_vue_dist_vue_runtime_esm-bundler_js-_7a230","node_modules_vue_dist_vue_runtime_esm-bundler_js-_7a231"],{8756(e,_,u){u.d(_,{createApp:()=>s.createApp});var s=u(53751)}}]);