"use strict";(self.webpackChunkcalendar=self.webpackChunkcalendar||[]).push([["node_modules_nextcloud_vue_dist_components_NcSelect_index_mjs"],{3710(e,c,d){d.r(c),d.d(c,{default:()=>n.N});var n=d(42133)}}]);